@@ -49,6 +49,7 @@ extern "C"
 #define ACVP_CIPHERTYPE_KDF	0x0200000000000000ULL
 #define ACVP_CIPHERTYPE_AUX	0x0400000000000000ULL
 #define ACVP_CIPHERTYPE_XOF	0x0800000000000000ULL
+#define ACVP_CIPHERTYPE_KAS	0x1000000000000000ULL
 
 /* AES */
 #define ACVP_ECB		(ACVP_CIPHERTYPE_AES  | 0x0000000000000001ULL)
@@ -181,6 +182,7 @@ extern "C"
 #define ACVP_KDF_COMPONENT	(ACVP_CIPHERTYPE_KDF  | 0x0000000000000001ULL)
 #define ACVP_KDF_800_108	(ACVP_CIPHERTYPE_KDF  | 0x0000000000000002ULL)
 #define ACVP_HKDF		(ACVP_CIPHERTYPE_KDF  | 0x0000000000000004ULL)
+#define ACVP_PBKDF		(ACVP_CIPHERTYPE_KDF  | 0x0000000000000008ULL)
 #define ACVP_KDF_MASK		(ACVP_CIPHERTYPE_KDF  | 0x000000000000000fULL)
 
 #define ACVP_KDF_108_DOUBLE_PIPELINE					\
@@ -196,6 +198,42 @@ extern "C"
 #define ACVP_KDF_108_BEFORE_ITERATOR					\
 				(ACVP_CIPHERTYPE_KDF  | 0x0000000000000800ULL)
 
+/* SP800-55B rev 2 */
+#define ACVP_KTS_IFC		(ACVP_CIPHERTYPE_KAS | 0x0000000000000001ULL)
+#define ACVP_KTS_SCHEMA_OAEP_BASIC					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000000010ULL)
+#define ACVP_KTS_SCHEMA_OAEP_PARTY_V_CONF				\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000000020ULL)
+#define ACVP_KAS1_SCHEMA_BASIC						\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000000040ULL)
+#define ACVP_KAS1_SCHEMA_PARTY_V_CONF					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000000080ULL)
+#define ACVP_KAS2_SCHEMA_BASIC						\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000000100ULL)
+#define ACVP_KAS2_SCHEMA_BILATERAL_CONF					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000000200ULL)
+#define ACVP_KAS2_SCHEMA_PARTY_U_CONF					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000000400ULL)
+#define ACVP_KAS2_SCHEMA_PARTY_V_CONF					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000000800ULL)
+
+#define ACVP_KAS_KEYGEN_RSAKPG1_BASIC					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000001000ULL)
+#define ACVP_KAS_KEYGEN_RSAKPG1_PRIME_FACTOR				\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000002000ULL)
+#define ACVP_KAS_KEYGEN_RSAKPG1_CRT					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000004000ULL)
+#define ACVP_KAS_KEYGEN_RSAKPG2_BASIC					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000008000ULL)
+#define ACVP_KAS_KEYGEN_RSAKPG2_PRIME_FACTOR				\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000010000ULL)
+#define ACVP_KAS_KEYGEN_RSAKPG2_CRT					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000020000ULL)
+#define ACVP_KAS_ENCODING_NONE						\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000040000ULL)
+#define ACVP_KAS_ENCODING_CONCATENATION					\
+				(ACVP_CIPHERTYPE_KAS | 0x0000000000080000ULL)
+
 #define ACVP_UNKNOWN		0x0000000000000000ULL
 
 #ifdef __cplusplus
