@@ -626,12 +626,19 @@ static int sym_mct_aes_helper(const struct json_array *processdata,
 				       (parsed_flags & FLAG_OP_ENC) ?
 				        "pt" : "ct", &vector->data));
 
+		free_buf(&vector->inner_loop_final_cj1);
+
 		for (iloop = 0; iloop < 999; iloop++) {
 			struct buffer tmp;
 
 			logger_binary(LOGGER_DEBUG, vector->data.buf,
 				      vector->data.len, "MCT source data");
 			CKINT(sym_backend->mct_update(vector, parsed_flags));
+
+			/* backend implemented inner loop */
+			if (vector->inner_loop_final_cj1.len)
+				break;
+
 			logger_binary(LOGGER_DEBUG, vector->data.buf,
 				      vector->data.len, "MCT calculated data");
 
@@ -670,28 +677,38 @@ static int sym_mct_aes_helper(const struct json_array *processdata,
 			}
 		}
 
-		/* we need that for key calculation */
-		if (vector->cipher == ACVP_ECB)
-			memcpy(calc_data.buf, vector->data.buf,
-			       vector->data.len);
-
 		/* final invocation without subsequent shuffling */
-		CKINT(sym_backend->mct_update(vector, parsed_flags));
+		if (vector->inner_loop_final_cj1.len) {
+			if (calc_data.len != vector->inner_loop_final_cj1.len) {
+				logger(LOGGER_ERR,
+				       "backend inner loop C[j-1] length unexpected\n");
+				ret = -EINVAL;
+				goto out;
+			}
+			memcpy(calc_data.buf, vector->inner_loop_final_cj1.buf,
+			       calc_data.len);
+		} else {
+			/* we need that for key calculation */
+			if (vector->cipher == ACVP_ECB)
+				memcpy(calc_data.buf, vector->data.buf,
+				       vector->data.len);
+			CKINT(sym_backend->mct_update(vector, parsed_flags));
 
-		/* Enqueue generated byte into calc_data */
-		if (vector->cipher == ACVP_CFB8) {
-			cfb_byte_for_next_round =
-				calc_data.buf[calc_data.len - 16];
-			sym_mct_cfb8_enqueue(&calc_data,
-					     vector->data.buf[0]);
-		}
+			/* Enqueue generated byte into calc_data */
+			if (vector->cipher == ACVP_CFB8) {
+				cfb_byte_for_next_round =
+					calc_data.buf[calc_data.len - 16];
+				sym_mct_cfb8_enqueue(&calc_data,
+						     vector->data.buf[0]);
+			}
 
-		/* Enqueue generated bit into calc_data */
-		if (vector->cipher == ACVP_CFB1) {
-			cfb_byte_for_next_round =
-				calc_data.buf[calc_data.len - 16] & 1<<7;
-			sym_mct_cfb1_enqueue(&calc_data,
-					     vector->data.buf[0]);
+			/* Enqueue generated bit into calc_data */
+			if (vector->cipher == ACVP_CFB1) {
+				cfb_byte_for_next_round =
+					calc_data.buf[calc_data.len - 16] & 1<<7;
+				sym_mct_cfb1_enqueue(&calc_data,
+						     vector->data.buf[0]);
+			}
 		}
 
 		CKINT(sym_backend->mct_fini(vector, parsed_flags));
